import 'package:args/args.dart';

/// Base class for commands for daily_programmer executable.

import 'package:args/command_runner.dart';
import 'package:daily_programmer_client_dart/src/util/entity_name.dart';

/// Base class for commands for daily_programmer executable.
abstract class BaseCommand extends Command {
  /// The name of the executable being run.
  static const String binaryName = 'daily_programmer_dart_cli';

  @override
  ArgParser get argParser => _argParser;
  final _argParser = new ArgParser(allowTrailingOptions: true);

  /// Reads argument for current command.
  String readArg(String errorMessage) {
    var args = argResults.rest;

    if (args == null || args.isEmpty) {
      // Usage is provided by command runner.
      throw new UsageException(errorMessage, '');
    }

    final arg = args.first;
    args = args.skip(1);

    if (args.isNotEmpty) {
      throw new UsageException('Unexpected argument $args', '');
    }

    return arg;
  }

  /// Reads argument for current command and create an EntityName.
  EntityName readArgAsEntityName(String errorMessage) =>
      getEntityName(readArg(errorMessage));

  /// If exist, return [EntityName] of entity.
  EntityName getEntityName(String entity) {
    EntityName entityName;

    try {
      entityName = new EntityName(entity);
      // ignore: avoid_catching_errors
    } on ArgumentError catch (error) {
      throw new UsageException(error.message, '');
    }

    return entityName;
  }
}
