import 'dart:async';

import 'package:daily_programmer_client_dart/src/app/base_command.dart';
import 'package:daily_programmer_client_dart/src/generator/challenge.dart';
import 'package:daily_programmer_client_dart/src/util/path_tool.dart';

/// Handles the `challenge` daily_programmer command.
class ChallengeCommand extends BaseCommand {
  static const _dryRunFlag = 'dry-run';
  static const _pathOption = 'path';

  /// Handles the `challenge` command with flag.
  ChallengeCommand() {
    argParser
      ..addFlag(_dryRunFlag,
          help: 'Don\'t generate, but lists files that were to be generated.')
      ..addOption(_pathOption,
          abbr: 'p',
          help: 'Project root path, a existing folder will be needed unde this '
              'path for the challenge.',
          defaultsTo: '.');
  }

  @override
  String get description => 'Generate a new challenge.';

  @override
  String get name => 'challenge';

  @override
  String get invocation =>
      '${BaseCommand.binaryName} $name <challenge_(name|number)> '
      '[--path <project/path>] [--dry-run]';

  @override
  Future run() async => await new ChallengeGenerator(
          readArgAsEntityName('Challenge name is needed.'), _projectPath,
          dryRun: _dryRun)
      .generate();

  bool get _dryRun => argResults[_dryRunFlag];
  String get _projectPath => getNormalizedPath(argResults[_pathOption]);
}
