import 'dart:io';

import 'package:daily_programmer_client_dart/src/util/app_logger.dart';

/// File writer helper.
class FileWriter {
  /// Public instance of static FileWriter.
  static FileWriter writer = new FileWriter._();

  FileWriter._();

  /// Writes content to [destination]. Throws StateError if
  /// destination exists. Folder will be created if not exists.
  void write(String destination, String content, {bool dryRun = false}) {
    final file = new File(destination);

    if (file.existsSync()) {
      throw new StateError('File $destination already exists');
    }

    AppLogger.log.info('Saving $destination');
    if (!dryRun) {
      if (!file.parent.existsSync()) {
        file.parent.createSync(recursive: true);
      }
      file.writeAsStringSync(content);
    }
  }
}
